InRoomChatMessage class abstract

在房间里获取聊天消息实例.

Constructors

InRoomChatMessage()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getChatMessageType() int
获取聊天消息类型
getContent() String
获取聊天内容
getMsgId() String
获取消息ID
getReceiverDisplayName() String
获取接收消息的用户的屏幕名称。
getReceiverUserId() String
获取接收消息的用户的ID
getSenderDisplayName() String
获取发送消息的用户的屏幕名称
getSenderUserId() String
获取发送消息的用户的ID
getTime() int
获取消息发送的时间。
isChatToAll() bool
检查消息是否发送给会议中的所有用户
isChatToAllPanelist() bool
检查消息是否发送给所有参加会议的小组成员
isChatToWaitingRoom() bool
检查消息是否发送给等待室用户
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setChatToAll(bool chatToAll) → void
发送消息给所有用户
setChatToAllPanelist(bool chatToAllPanelist) → void
发送消息给所有参加会议的小组成员
setChatToWaitingRoom(bool chatToWaitingRoom) → void
发送消息给等待室用户
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited