NEAuthService class abstract

用于在完成SDK登录鉴权后,查询当前已登录账号的基本信息,如个人房间号信息 通过NERoomKit.getAuthService获取账号服务的实例

Constructors

NEAuthService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addAuthListener(NERoomAuthListener listener) → void
注册登录状态监听器
getAccountInfo() NEAccountInfo?
账号信息
loginWithAccount(String username, String password) Future<NEResult<void>>
登录鉴权。在已登录状态下可以创建和加入房间,但在未登录状态下只能加入房间
loginWithSSOToken(String ssoToken) Future<NEResult<void>>
登录鉴权。在已登录状态下可以创建和加入房间,但在未登录状态下只能加入房间
loginWithToken(String accountId, String token) Future<NEResult<void>>
登录鉴权。在已登录状态下可以创建和加入房间,但在未登录状态下只能加入房间
logout() Future<NEResult<void>>
注销当前已登录的账号
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeAuthListener(NERoomAuthListener listener) → void
注销登录状态监听器
toString() String
A string representation of this object.
inherited
tryAutoLogin() Future<NEResult<void>>
用户自动登录

Operators

operator ==(Object other) bool
The equality operator.
inherited