NEFileAttachment class

source form FileAttachment

Implementers

Constructors

NEFileAttachment({int? size, String? md5, required String url, required String displayName, String? extension, int? expire})

Properties

displayName String
文件显示名
getter/setter pair
expire int?
过期时间(仅对文件类型有效)
getter/setter pair
extension String?
文件后缀名
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
md5 String?
文件内容md5
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int?
文件大小
getter/setter pair
url String
文件下载地址
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited