NEHttpApiService class abstract

HttpApi服务

Constructors

NEHttpApiService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendRequest(NEHttpApiRequest request) Future<NEResult>
sendRequestOverPassThrough(NEHttpApiRequest request) Future<NEResult>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited