NEImageAttachment class
source form ImageAttachment
- Inheritance
-
- Object
- NEFileAttachment
- NEImageAttachment
Constructors
Properties
- displayName ↔ String
-
文件显示名
getter/setter pairinherited
- expire ↔ int?
-
过期时间(仅对文件类型有效)
getter/setter pairinherited
- extension ↔ String?
-
文件后缀名
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- height ↔ int?
-
图片高
getter/setter pair
- md5 ↔ String?
-
文件内容md5
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size ↔ int?
-
文件大小
getter/setter pairinherited
- url ↔ String
-
文件下载地址
getter/setter pairinherited
- width ↔ int?
-
图片宽
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited