NEInRoomAudioController class abstract
房间内音频控制器.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
adjustPlaybackSignalVolume(
int volume) → Future< NEResult< void> > -
调节播放音量
加入频道前后都可以调用
调节范围为:
0~4000: 静音 100: 原始音量 (默认) 400: 最大可为原始音量的 4 倍(自带溢出保护) -
adjustRecordingSignalVolume(
int volume) → Future< NEResult< void> > -
调节录音音量
加入频道前后都可以调用
调节范围为:
0~4000: 静音 100: 原始音量 (默认) 400: 最大可为原始音量的 4 倍(自带溢出保护) -
canUnmuteMyAudio(
) → bool - 查询本地是否可以开启音频
-
enableAudioVolumeIndication(
bool enable, int interval) → Future< NEResult< void> > - 启用说话者音量提示。该方法允许 SDK 定期向 App 反馈当前谁在说话以及说话者的音量
-
enableEarBack(
bool enabled, int volume) → Future< NEResult< void> > - 开启或关闭耳返
-
isMuteOnEntryOn(
) → bool - 查询是否启用与会者加入房间时自动使其静音
-
isMyLoudSpeakerOn(
) → Future< bool> - 查询当前发言者的扬声器状态
-
isPlayoutDeviceMute(
) → Future< bool> - 获取当前音频播放设备是否静音
-
isRecordDeviceMute(
) → Future< bool> - 获取音频采集设备是否静音
-
lowerAllHands(
) → Future< NEResult< void> > - 把所有的用户手放下
-
lowerHand(
String userId) → Future< NEResult< void> > - 将某个用户的手放下
-
lowerMyHand(
) → Future< NEResult< void> > - 取消举手
-
muteAllParticipantsAudio(
bool allowUnmuteSelf) → Future< NEResult< void> > -
开启/关闭本地语音采集以及发送
主持人将所有与会者静音,
allowUnmuteSelftrue:允许取消自己静音;反之,不允许 -
muteMyAudio(
bool isMute) → Future< NEResult< void> > -
设置自己音频静音或者开启,
isMutetrue: 关闭/false:开启 -
muteParticipantAudio(
String userId, bool isMute) → Future< NEResult< void> > - 主持人将与会者的音频静音
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
raiseMyHand(
) → Future< NEResult< void> > - 举手
-
setEarBackVolume(
int volume) → Future< NEResult< void> > - 设置耳返音量
-
setMyLoudSpeakerOn(
bool on) → Future< NEResult< void> > -
设置是否可以切换当前房间的音频输出源时是否打开扬声器,
ontrue: 打开/false:关闭 -
setPlayoutDeviceMute(
bool isMute) → Future< NEResult< void> > - 设置是否音频播放静音
-
setRecordDeviceMute(
bool isMute) → Future< NEResult< void> > - 设置是否音频采集静音
-
startAudioDump(
) → Future< NEResult< void> > - 开始音频 dump
-
stopAudioDump(
) → Future< NEResult< void> > - 结束音频dump
-
subscribeAllRemoteAudioStream(
) → Future< NEResult< void> > - 订阅会议内全部音频流
-
subscribeRemoteAudioStream(
String userId) → Future< NEResult< void> > - 订阅会议内某一音频流
-
syncLocalAudioStatus(
) → Future< NEResult< void> > - 同步音频状态
-
toString(
) → String -
A string representation of this object.
inherited
-
unmuteAllParticipantsAudio(
) → Future< NEResult< void> > - 主持人取消全体静音
-
unsubscribeAllRemoteAudioStream(
) → Future< NEResult< void> > - 取消订阅会议内全部音频流
-
unsubscribeRemoteAudioStream(
String userId) → Future< NEResult< void> > - 取消订阅会议内某一音频流
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited