NEInRoomUserController class abstract
在房间里获取美颜控制器实例.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
changeMyName(
String name) → Future< NEResult< void> > - 房间内改名
-
makeHost(
String userId) → Future< NEResult< void> > - 移交主持人
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeUser(
String userId) → Future< NEResult< void> > - 移除用户
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited