NEInRoomVideoController class abstract

控制房间内自己、其他人的视频状态

Constructors

NEInRoomVideoController()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

askParticipantStartVideo(String userId) Future<NEResult<void>>
主持人请求房间内其他用户开启视频
attachRendererToUserVideoStream(NERtcVideoRenderer renderer, String userId) Future<NEResult<void>>
添加为用户视频画布
attachRendererToUserVideoSubStream(NERtcVideoRenderer renderer, String userId) Future<NEResult<void>>
添加为用户辅流视频画布
canSwitchCamera() bool
查询本地是否可以切换摄像头
canUnmuteMyVideo() bool
查询本地是否可以开启视频
getPinnedUserId() String?
获取当前焦点视频用户ID
isMyVideoMuted() bool
查询本地视频是否关闭
isUserPinned(String userId) bool
查询对应用户是否被设置为焦点视频
muteMyVideo(bool mute) Future<NEResult<void>>
开启/关闭本地视频
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pinVideo(String userId, bool on) Future<NEResult<void>>
主持人取消设置/设置对应用户为焦点视频
stopParticipantVideo(String userId) Future<NEResult<void>>
主持人关闭房间内其他用户的视频
subscribeRemoteVideoStream(String userId, int streamType) Future<NEResult<void>>
订阅房间内某一视频流
subscribeRemoteVideoSubStream(String userId) Future<NEResult<void>>
订阅房间内某一视频辅流
switchCamera() Future<bool>
旋转本地视频 bool rotateMyVideo(int rotation); 查询本地摄像头设备 List
syncLocalVideoStatus() Future<NEResult<void>>
同步视频状态
toString() String
A string representation of this object.
inherited
unsubscribeRemoteVideoStream(String userId) Future<NEResult<void>>
取消订阅房间内某一视频流
unsubscribeRemoteVideoSubStream(String userId) Future<NEResult<void>>
取消订阅房间内某一视频辅流

Operators

operator ==(Object other) bool
The equality operator.
inherited