NEJoinRoomParams class
提供加入房间时必要的额外参数,如房间ID、用户房间昵称等
- Inheritance
-
- Object
- NERoomParams
- NEJoinRoomParams
Constructors
- NEJoinRoomParams({required String roomId, required String displayName, String? password, String? tag})
- NEJoinRoomParams.fromMap(Map map)
Properties
- displayName → String
-
房间中的用户昵称,不能为空
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- password → String?
-
房间密码;
创建房间时,如果密码不为空,会创建带指定密码的房间
加入带密码的房间时,需要指定密码
finalinherited
- roomId → String?
-
指定要创建或加入的目标房间ID
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tag → String?
-
会议中的用户成员标签,自定义,最大长度50
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited