NEPreRoomBeautyController class abstract

Inheritance

Constructors

NEPreRoomBeautyController()

Properties

apiLogger → Alogger
no setterinherited
beautyLevels List<NERtcFaceUnityParams>
默认美颜配置表,等级对应数组
finalinherited
commonLogger → Alogger
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createVideoPreview() Future<NERtcVideoRenderer?>
创建美颜预览View
enableBeauty(bool enable) Future<NEResult<void>>
inherited
getBeautyFaceValue() Future<NEResult<int>>
inherited
isBeautyEnabled() bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
release() → void
inherited
setBeautyFaceValue(int value, {bool save = true}) Future<NEResult<void>>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited