NERoomAudioRecvStats class

Constructors

NERoomAudioRecvStats({required String userId, int? kbps, int? lossRate, int? volume, int? totalFrozenTime, int? frozenRate})

Properties

frozenRate int?
平均音频卡顿率
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
kbps int?
接收到的码率 (kbps)
getter/setter pair
lossRate int?
丢包率
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalFrozenTime int?
音频卡顿累计时长,从收到远端用户音频算起
getter/setter pair
userId String
用户 ID,指定是哪个用户的音频流
getter/setter pair
volume int?
音量0-100
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited