NERoomConnectFailReason class
房间失败原因
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- joinChannelError → const int
- 加入频道失败
- roomNotExist → const int
- 房间不存在
- rtcInitError → const int
- rtc 模块初始化失败
- syncDataError → const int
- 同步房间信息失败