NERoomDisconnectReason class

房间结束原因

Constructors

NERoomDisconnectReason()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

authInfoExpired → const int
登录信息过期
closeByHost → const int
房间被主持人关闭
closeBySelf → const int
用户主动关闭房间
leaveBySelf → const int
用户主动离开房间
loginOnOtherDevice → const int
账号重复登录
rejoinChannelError → const int
重新加入频道失败
removedByHost → const int
被主持人移除房间
rtcSDKError → const int
rtc sdk error