NERoomKit class abstract

房间SDK全局接口,提供初始化、管理其他房间相关子服务的能力

Constructors

NERoomKit()

Properties

config NERoomKitConfig?
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAuthService() NEAuthService
获取用于查询账号信息的账号服务
getHttpApiService() NEHttpApiService
房间网络服务
getInRoomService() NEInRoomService?
获取房间内服务
getPreRoomService() NEPreRoomService
获取房间前服务
getRoomService() NERoomService
获取用于创建或加入房间的房间服务。
getSettingsService() NESettingsService
获取房间设置服务
initialize(NERoomKitConfig config) Future<NEResult<void>>
初始化SDK
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance NERoomKit
获取房间SDK实例
no setter