NERoomKitConfig class

提供房间SDK初始化时必要的参数和配置信息

Constructors

NERoomKitConfig({required String appKey, String? serverConfig, bool reuseNIM = false, Map<String, dynamic>? extras, ALoggerConfig aLoggerConfig = const ALoggerConfig()})

Properties

aLoggerConfig ALoggerConfig
日志参数配置
final
appKey String
房间App Key,不能为空
final
extras Map<String, dynamic>?
final
hashCode int
The hash code for this object.
no setteroverride
reuseNIM bool
是否复用IM通道
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serverConfig String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override