NERoomLifeCycleObserverOwner class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addObserver(
NERoomLifeCycleObserver observer) → void -
clear(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyRoomConnectFail(
int reason) → void -
notifyRoomOnConnected(
) → void -
notifyRoomOnConnecting(
) → void -
notifyRoomOnDisConnected(
int reason) → void -
notifyRoomOnDisConnecting(
) → void -
notifyRoomOnIdle(
) → void -
removeObserver(
NERoomLifeCycleObserver observer) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- connected → const int
- connectFail → const int
- connecting → const int
- disconnected → const int
- disconnecting → const int
- idle → const int