NERoomNetworkQualityInfo class

用户的网络质量

Constructors

NERoomNetworkQualityInfo({required String userId, int? txQuality, int? rxQuality})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
rxQuality int?
下行网络质量 NERTcNetworkStatus
getter/setter pair
txQuality int?
上行网络质量 NERTcNetworkStatus
getter/setter pair
userId String
用户 ID
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited