NERoomOptions class

提供创建和加入房间时必要的基本配置信息和选项开关,通过这些配置和选项可控制入会时的行为,如音视频的开启状态等

See also:

Implementers

Constructors

NERoomOptions({bool noVideo = true, bool noAudio = true, Map<String, dynamic> extras = const <String, dynamic>{}})

Properties

extras Map<String, dynamic>
额外选项
final
hashCode int
The hash code for this object.
no setterinherited
noAudio bool
配置入会时是否关闭本端音频,默认为true,即关闭音频,但在房间中可重新打开
final
noVideo bool
配置入会时是否关闭本端视频,默认为true,即关闭视频,但在房间中可重新打开
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited