NERoomService class abstract

提供房间相关的服务接口,诸如创建房间、加入房间、添加房间状态监听等。可通过 NERoomKit.getRoomService 获取对应的服务实例

Constructors

NERoomService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getCurrentRoomInfo() NERoomInfo?
获取当前房间详情。如果当前无正在进行中的房间,则回调数据对象为空 NERoomInfo
joinRoom(NEJoinRoomParams param, NEJoinRoomOptions? opts) Future<NEResult<JoinRoomInfo>>
加入一个当前正在进行中的房间,已登录或未登录均可加入房间。加入房间成功后,SDK会拉起房间页面,调用方不用做其他操作
leaveCurrentRoom(bool closeIfHost) Future<NEResult<void>>
离开房前房间
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startRoom(NEStartRoomParams param, NEStartRoomOptions? opts) Future<NEResult<JoinRoomInfo>>
创建一个新的房间,只有完成SDK的登录鉴权操作才允许创建房间。创建房间成功后,SDK会拉起房间页面,调用方不用做其他操作
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited