NERoomType class

Constructors

NERoomType()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

now → const int
now 即刻会议
person → const int
person 个人会议 使用个人会议号开始的即刻会议类型为个人会议
schedule → const int
schedule 预约会议