RoomErrorCode class

Constructors

RoomErrorCode()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getMsg(String? msg, [String? defaultTips]) String

Constants

accountNotExist → const int
allocationAccountFail → const int
allowSelfAudioOn → const int
alreadyInRoom → const int
当前存在未结束的房间
audioAlreadyOn → const int
audioNeedHandsUp → const int
cancelled → const int
取消
controlCodeError → const int
controlNotAllocationAccount → const int
failed → const int
通用失败
fetchAccountFail → const int
forbidden → const int
illegalPhone → const int
loginErrorAnonymousLoginNotSupport → const int
IM复用匿名登录失败,原因是不支持
loginErrorIMAccountNotMatch → const int
IM复用登录失败,原因是 IM-SDK 账号与 RoomKit 账号不匹配
loginErrorIMNotLogin → const int
IM复用登录失败,原因是 IM-SDK 未登录
loginPasswordError → const int
memberAudioError → const int
memberNotHasRoomId → const int
memberNotInRoom → const int
memberVideoError → const int
netError → const int
netTimeout → const int
networkError → const int
网络错误
nickError → const int
notFound → const int
notHostPermission → const int
notJoinRoomCannotKick → const int
notLogin → const int
接口调用失败,原因为SDK未登录
notSupport → const int
paramError → const int
接口调用失败,原因为参数校验不通过
paramsError → const int
paramsNull → const int
passwordError → const int
phoneAlreadyRegister → const int
phoneNotRegister → const int
roomAlreadyExist → const int
roomCidIsEmpty → const int
roomMemberOverLimit → const int
roomNotExist → const int
roomNotInProgress → const int
roomPasswordError → const int
roomPasswordNotPresent → const int
screenShareOverLimit → const int
serverError → const int
serverInnerError → const int
smsCodeOverLimit → const int
success → const int
服务端错误码
tokenError → const int
tvAccountNotExist → const int
unauthorized → const int
verifyError → const int
verifyInvalid → const int
versionNotCompatible → const int