UserProfile class

Constructors

UserProfile()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

accountId String?
self uid
no setter
accountToken String?
auth token
no setter
appKey String
meeting app key
no setter
displayName String?
display name
getter/setter pair
imAccid String?
no setter
imAppKey String?
im app key
no setter
imToken String?
no setter
isAnonymous bool
is anonymous user
getter/setter pair
lastChannelId int?
last av room cname
getter/setter pair
lastMeetingId String?
last meeting id
getter/setter pair
meetingId String?
self meeting id
no setter
nickname String?
self nickname,目前仅对外接口_NEAccountServiceImpl.getAccountInfo()使用
no setter
nrtcAppKey String?
nrtc app key
no setter
shortId String?
self short id
no setter