NEAccountInfo class
Constructors
- NEAccountInfo(String accountId, String accountName, String roomId, String? shortRoomId)
Properties
- accountId → String
-
账号ID
final
- accountName → String
-
账户名
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- roomId → String
-
个人房间号,该房间号可在创建房间时使用
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shortRoomId → String?
-
个人房间短号,该房间号可在创建房间时使用
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited