NEChatRoomImageMessage class
- Inheritance
-
- Object
- NEChatRoomMessage
- NEChatRoomImageMessage
Constructors
Properties
- attachment → NEImageAttachment
-
no setter
- chatRoomUserInfo → NEChatRoomUserInfo
-
no setterinherited
- content ↔ String?
-
聊天消息内容
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- msgStatus → int
-
no setterinherited
- msgType → int
-
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
senderExtension
↔ Map<
String, dynamic> ? -
获取聊天室消息扩展属性
getter/setter pairinherited
- time ↔ int?
-
getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited