NEChatRoomMessage class abstract
Constructors
-
NEChatRoomMessage({Map<
String, dynamic> ? senderExtension, String? content, int? time})
Properties
- chatRoomUserInfo → NEChatRoomUserInfo
-
no setter
- content ↔ String?
-
聊天消息内容
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- msgStatus → int
-
no setter
- msgType → int
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
senderExtension
↔ Map<
String, dynamic> ? -
获取聊天室消息扩展属性
getter/setter pair
- time ↔ int?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited