NEInRoomChatController class abstract
在房间里获取聊天室控制器实例.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
enterChatRoom(
) → Future< NEResult< void> > - 加入聊天室
-
exitChatRoom(
) → Future< NEResult< void> > - 退出聊天室
-
hasEnterChatRoom(
) → bool - 查询是否在当前房间中开启聊天
-
isChatroomEnabled(
) → bool - 查询当前会议聊天室是否可用
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sendChatRoomMessage(
NEChatRoomMessage message) → Future< NEResult< NEChatRoomMessage> > -
toString(
) → String -
A string representation of this object.
inherited
-
updateChatRoomUserRole(
NEChatRoomUserRole chatRoomUserInfo, {Map< String, dynamic> ? extension}) → Future<NEResult< void> > - 更新聊天室用户角色信息
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited