NEInRoomLiveInfo class abstract
房间内直播条目
Constructors
- NEInRoomLiveInfo()
-
factory
Properties
- chatRoomId → String?
-
直播聊天室id
no setter
- enable → bool
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hlsPullUrl → String?
-
hls 拉流地址
no setter
- httpPullUrl → String?
-
http 拉流地址
no setter
- liveChatRoomEnable ↔ bool
-
是否开启聊天室
getter/setter pair
- liveLayout ↔ NELiveLayout
-
直播布局
getter/setter pair
- liveUrl → String?
-
直播地址
no setter
- password ↔ String?
-
直播密码
getter/setter pair
- rtmpPullUrl → String?
-
rtmp 拉流地址
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → NERoomItemLiveState
-
直播状态
no setter
- title ↔ String?
-
getter/setter pair
-
userList
↔ List<
String> ? -
getter/setter pair
- webAccessControlLevel ↔ NELiveAuthLevel
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited