NEInRoomLiveStreamController class abstract
房间直播控制器
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getLiveStreamInfo(
) → NEInRoomLiveInfo? - 获取当前直播信息
-
isLiveStreamEnabled(
) → bool - 查询直播是否正在进行中
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
startLiveStream(
NEInRoomLiveInfo live) → Future< NEResult< NEInRoomLiveInfo> > - 主持人开启直播
-
stopLiveStream(
) → Future< NEResult< void> > - 主持人结束直播
-
toString(
) → String -
A string representation of this object.
inherited
-
updateLiveStream(
NEInRoomLiveInfo live) → Future< NEResult< NEInRoomLiveInfo> > - 主持人更新直播状态
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited