NEInRoomScreenShareController class abstract
屏幕共享控制器
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getScreenSharingUserId(
) → String? - 获取当前正在屏幕共享的用户ID
-
isOtherSharing(
) → bool - 其他人是否正在共享屏幕
-
isSharingScreen(
) → bool - 本端是否正在共享屏幕
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
开启本地屏幕共享
config屏幕共享相关参数broadcastAppGroupios屏幕共享必需 - 主持人操作停止用户屏幕共享
- 停止本地屏幕共享
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited