NEInRoomUserInfo class abstract
Constructors
Properties
- audioStatus → NERoomAudioStatus
-
音频状态
no setter
- clientType → int
-
客户端类型
no setter
- displayName → String
-
房间用户昵称
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isPinned → bool
-
是否为焦点视频
no setter
- isScreenSharing → bool
-
是否正在屏幕共享
no setter
- isWhiteBoardSharing → bool
-
是否正在白板共享
no setter
- raiseHandDetail → NERaiseHandDetail
-
当前举手状态
no setter
- roleType → int
-
角色身份,1成员,2主持人,3管理员,4隐藏
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tag → String?
-
成员标签,自定义,最大长度50
no setter
- userId → String
-
房间用户id
no setter
- videoStatus → NERoomVideoStatus
-
视频状态
no setter
- whiteBoardInteractStatus → NERoomWhiteBoardInteractionStatus
-
白板相互协作权限
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited