NEInRoomWhiteboardController class abstract
在房间里获取白板控制器实例.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getWhiteboardSharingUserId(
) → String? - 获取当前正在共享白板的用户ID
-
getWhiteboardUrl(
) → String? -
hasInteractPrivilege(
) → bool - 查询自己是否有编辑特权
-
hasInteractPrivilegeWithUserId(
String userId) → bool - 查询某用户是否有编辑能力
-
initWhiteboardJavascriptChannel(
Future< WebViewController> javascriptController, NEWhiteboardErrorCallback? onWhiteboardErrorCallback) → JavascriptChannel -
获取展示白板用的
WebView -
isOtherSharing(
) → bool - 查询其他用户是否正在共享白板
-
isSharingWhiteboard(
) → bool - 查询当前用户是否正在共享白板
-
isWhiteboardSharing(
String userId) → bool - 查询用户是否正在共享白板
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
release(
) → void - 释放白板
-
setInteractPrivilege(
String userId, bool enable) → Future< NEResult< void> > - 设置是否有权限开启编辑
-
showWhiteboardTools(
bool show) → Future< NEResult< void> > - 设置显示白板工具栏
- 开启本地白板共享
- 主持人操作停止用户白板共享
- 停止本地白板共享
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited