NEJoinRoomOptions class
提供加入房间时必要的配置信息和选项开关,如音频、视频开关
- Inheritance
-
- Object
- NERoomOptions
- NEJoinRoomOptions
Constructors
- NEJoinRoomOptions({bool? noVideo, bool? noAudio})
Properties
-
extras
→ Map<
String, dynamic> -
额外选项
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- noAudio → bool
-
配置入会时是否关闭本端音频,默认为true,即关闭音频,但在房间中可重新打开
finalinherited
- noVideo → bool
-
配置入会时是否关闭本端视频,默认为true,即关闭视频,但在房间中可重新打开
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited