NEPreRoomService class abstract
房间前服务, 主要提供房间开始前的一系列方法, eg: 房间预定
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addScheduledRoomStatusListener(
ScheduledRoomStatusListener< List< listener) → voidNERoomItem> > - 注册监听预定房间状态变更回调
-
cancelRoom(
int roomUniqueId) → Future< NEResult< void> > - 取消预约房间,开始前可以取消
-
editRoom(
NERoomItem item) → Future< NEResult< NERoomItem> > - 编辑预约房间
-
getPreRoomBeautyController(
) → NEPreRoomBeautyController - 美颜控制器实例.
-
getRoomItemByUniqueId(
int roomUniqueId) → Future< NEResult< NERoomItem> > - 根据唯一id获取房间信息
-
getRoomList(
List< NERoomItemStatus> status) → Future<NEResult< List< >NERoomItem> > - 根据房间状态查询房间信息列表, 不传默认返回NEMeetingItemStatus.init, NEMeetingItemStatus.started
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeScheduledRoomStatusListener(
ScheduledRoomStatusListener< List< listener) → voidNERoomItem> > - 反注册监听预定房间状态变更回调
-
scheduleRoom(
NERoomItem item) → Future< NEResult< NERoomItem> > - 预约房间
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited