NERoomInfo class abstract
Constructors
Properties
- audioAllMute → bool
-
是否有全体禁音,0:否,1:有
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hostUserId → String
-
主持人帐号id
no setter
- liveStreamInfo → NEInRoomLiveInfo?
-
直播设置
no setter
- locked → bool
-
是否锁定
no setter
- password → String?
-
密码
no setter
- pinnedUserId → String?
-
焦点视频帐号id
no setter
- roomId → String
-
房间ID
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scheduleEndTime → int
-
预约结束时间
no setter
- scheduleStartTime → int
-
预约开始时间
no setter
- screenSharingUserId → String?
-
屏幕共享者
no setter
- settings → NERoomItemSettings?
-
设置
no setter
- shortRoomId → String?
-
短号ID
no setter
- sipCid → String?
-
Sip会议ID
no setter
- subject → String
-
主题
no setter
- type → int
-
类型
NERoomType
no setter
- uniqueId → int
-
预定成功后, 服务器生成唯一id
no setter
-
userList
→ List<
NEInRoomUserInfo> -
成员列表
no setter
- whiteboardSharingUserId → String?
-
白板共享者
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited