NESettingsService class abstract
房间设置服务,可设置入会时、房间中的一些配置信息 如入会时的音视频开关选项,如果在入会时未指定NERoomOptions,则使用该设置服务提供的默认值 该设置服务使用设备本地存储,暂不支持漫游
- Inheritance
-
- Object
- ChangeNotifier
- ValueNotifier<
Map> - NESettingsService
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value ↔ Map
-
The current value stored in this notifier.
getter/setter pairinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
dispose(
) → void -
Discards any resources used by the object.
inherited
-
isBeautySupported(
) → bool - 查询是否开启美颜功能
-
isChatroomSupported(
) → bool - 查询当前应用是否支持聊天室功能
-
isCloudRecordSupported(
) → bool - 查询是否为当前用户启用了云端录制,房间内本地属性
-
isLiveStreamSupported(
) → bool - 是否允许开启直播
- 屏幕共享功能是否可用 Android 均支持 iOS 12以上才支持
-
isWhiteboardSupported(
) → bool - 查询白板服务开关状态 return true-打开,false-关闭
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited