NEStartRoomOptions class
提供创建房间时必要的配置信息和选项开关,如音频、视频开关
- Inheritance
-
- Object
- NERoomOptions
- NEStartRoomOptions
Constructors
- NEStartRoomOptions({bool? noVideo, bool? noAudio, bool noCloudRecord = true, bool noChat = false})
Properties
-
extras
→ Map<
String, dynamic> -
额外选项
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- noAudio → bool
-
配置入会时是否关闭本端音频,默认为true,即关闭音频,但在房间中可重新打开
finalinherited
- noChat → bool
-
配置房间内是否开启聊天室功能
final
- noCloudRecord → bool
-
配置房间中是否显示显示云端录制状态
final
- noVideo → bool
-
配置入会时是否关闭本端视频,默认为true,即关闭视频,但在房间中可重新打开
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited